function [iy, id, ih, im, ss] =  ep2dat(time)
%
%=======================================================================================
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%    Converts epochal time to yr,day,hr,mn,sec
%    epochal time is defined by CSS to be the time in secs from 1970 day 0.
% 
% Input:
%  time
%
% Output:
%  iy = year
%  id = day of year (often called Julian day)
%  ih = hour of day
%  im = minutes
%  ss = seconds
%
% History:
%     2010-04-22 MB: noticed that for time past middle of the day it returnd next dat and also
%                    returns negative time elements. The following fix was applied after
%                    many tests that all failed!!!
%     2009 Bob Woodward
%
%=======================================================================================

      if time < 0.0
        error('ERROR in ep2dat -- epochal time < 0');
      end;
      nd  = time / 86400.;
      kd  = fix(nd);
      sec = time - (86400. * kd);
     
      % 
      % this is workaround for a problem that is observed with fix!
      % it appears that fix does not round down towards the smaller
      % integer when greater that 0.5. All tests failed ...MB 2010-04-22
      %
      if(sec < 0)
         kd = kd - 1;
         sec = time - (86400. * kd);
      end;

      ky  = 1970;
      idpy = 365;
      
      while kd >= idpy
          ky = ky + 1;
          kd = kd - idpy;
          idpy = 365;
          if mod(ky,4) == 0
              idpy=366;
          end;
      end;
      iy = ky;
      id = kd + 1;
      nh = sec / 3600.d0;
      ih = fix(nh);
      nm = (sec - (3600.d0 * ih)) / 60.d0 ;
      % 
      % this is workaround for a problem that is observed with fix!
      % it appears that fix does not round down towards the smaller
      % integer when greater that 0.5. All tests failed ...MB 2010-04-22
      %
      if(nm < 0)
         ih = ih - 1;
         nm = (sec - (3600.d0 * ih)) / 60.d0 ;
      end;
      im = fix(nm);
      ss = sec - 3600.d0*ih - 60.d0*im;

      % 
      % this is workaround for a problem that is observed with fix!
      % it appears that fix does not round down towards the smaller
      % integer when greater that 0.5. All tests failed ...MB 2010-04-22
      %
      if(ss < 0)
         im = im - 1;
         ss = sec - 3600.d0*ih - 60.d0*im;
      end;

