function [epoch] = epoch(iy,id,ih,im,sec)
%
%=======================================================================================
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%    Converts yr,day,hr,mn,sec to epochal time which is defined by CSS to
%    be the time in seconds from 1970 day 0.
%    Note that this version computes the real*8 number of seconds since
%    1970.
%
%    On input, sec can be greater than 60.
%
% input:
%    iy = year
%    id = day of year (often called Julian day)
%    ih = hour
%    im = minute
%    sec = seconds
%
% output:
%   epoch = time, in seconds, since the beginning of 1970
%
%
%  History:
%     2010-05-13 MB: there is a problem with losing decimal points and conversion to integer. 
%                    Using double for now to prevent the problem.
%     2009 Bob Woodward
%
%=======================================================================================

      ky = iy;
      if ky < 100
          ky = ky + 1900;
      end;
      if ky<1970 
          error('ERROR: year < 1970 in epoch');
      end;
      time = double((( (id-1)*24.d0 + ih*1.d0)*60.d0 + im*1.d0)*60.d0+sec*1.d0);
      while ky > 1970
          ky   = ky-1;
          idpy = 365;
          if mod(ky,4) == 0
              idpy=366;
          end;
          time = double(time + 86400.d0 * idpy);
      end;
      epoch = time;
