function [flag param] = get_custom_par(paramKey, paramFile)
%
%=======================================================================================
%
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%    Reads a custom GMV parameter file, and returns the corresponding value based on paramKey
%
% Input:
%    paramFile = file to read the parameters from 
%    paramKey = parameter key to extract
%
% Output:
%    param = array containing requested values
%
% History:
%     2010-08-02 MB
%
%=======================================================================================

% open the file for reading
%
fid = fopen(paramFile,'r'); 
flag = -1;
param='-';

while ~feof(fid) % loop until we find end of the file
    str = fgetl(fid); % get a line of text

    %
    % split the string into its component parts
    % assume that values are split with "|"
    %
    res = strread(str,'%s','delimiter','|');

    %
    % see if this is what we are looking for
    %
    if(strcmp(res{1},paramKey))
        %fprintf('[parse_event_file INFO] found the key: %s\n',paramKey);
        flag = 1;
        param = res{2};
        break;
    end; % if
end;

fclose(fid);
