function [stName, stCoord, seisData] = seisClean(stName, stCoord, seisData)
%
%=======================================================================================
%
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%   Removes latitude/longitude pairs with NaN/NaN and empty seismograms.
%
% Input:
%   ~Station Latitude (Lat):
%   ~Station Longitude (Lon):
%   ~Seismic Data (seisData): 
%
% Output:
%   ~Cleaned Station Latitude (Lat):
%   ~Cleaned Station Longitude (Lon):
%   ~Cleaned Seismic Data (seisData):
%
% Function Dependencies:
%
% History
%   2009-08-29 Andrew Lloyd
%
%=======================================================================================


r = size(stCoord,1);

id = find(~isnan(stCoord(1:r,2)) & ~isnan(stCoord(1:r,1)));

if (~isempty(id))
    stName = stName(id(:),:);
    stCoord = stCoord(id(:), :);
    seisData = seisData(id(:),:);
end %endIf
