function x = srmean(s)
%=======================================================================================
%
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%   Remove the mean from the amplitudes in the SAC structure
%
% Usage:
%   x = srmean(s);
%
% Change History:
%   2011-07-07 MB: per Debi Kilb suggestion changed mean(s(ns).d) to  mean(s(ns).d(1:s.npts))
%                  to restricted the mean to only values defined between 1 and npts
%=======================================================================================
%
%
[nr nseis] = size(s);
%
for ns = 1:nseis
    %
    x(ns) = s(ns);
    x(ns).d = s(ns).d - mean(s(ns).d(1:s.npts));
    %
    % reset the header amplitude values
    %
    x(ns).depmin = min(x(ns).d); 
    x(ns).depmax = max(x(ns).d); 
    x(ns).depmen = mean(x(ns).d);
    %
end
%
return
