function [ del , az ] = stadis2(lat1,lon1,lat2,lon2)
%
%=======================================================================================
%
% Copyright (C) 2011  Product Team, IRIS Data Management Center
%
%    This is a free software; you can redistribute it and/or modify
%    it under the terms of the GNU Lesser General Public License as
%    published by the Free Software Foundation; either version 3 of the
%    License, or (at your option) any later version.
%
%    This script is distributed in the hope that it will be useful, but
%    WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%    Lesser General Public License (GNU-LGPL) for more details.  The
%    GNU-LGPL and further information can be found here:
%    http://www.gnu.org/
%
%    You should have received a copy of the GNU Affero General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Description:
%    Computes the epicentral distance and azimuth from source to receiver.
%    Latitudes are converted to geocentric latitudes prior to performing
%    the computations (it is assumed that input latitudes are geographic).
%
% This version has "standard" inputs.
%  Input:
%    lat1 = source latitude (degrees)
%    lon1 = source longitdue (degrees)
%    lat2 = station latitude (degrees)
%    lon2 = station longitdue (degrees)
%
%  Output:
%    del   = epicentral distance (degrees)
%    az    = azimuth from source to receiver, measure from North (degrees)
%
%  History:
%     2009 Bob Woodward
%
%=======================================================================================
%
rad = 180.0 / pi;
%
% Convert source to to co-latitudes and co-longitudes, in degrees
%   colat = source colatitude
%   colon =   "    colongitude
%
colat = 90.0 - lat1;
colon = lon1;
if (colon < 0.0)
    colon = 360.0 + colon;
end;
%
% Convert station to to co-latitudes and co-longitudes, in radians
%   t1    = station colatidue
%   p1    =    "    colongitude
%
t1 = (90.0 - lat2) / rad;
p1 = lon2;
if (p1 < 0.0)
    p1 = 360.0 + p1;
end;
p1 = p1 / rad;
%
% Conversions are done - drop into some really old code
%
%  first do eq coords.
%  use geocentric e.q.colat
%
t0=geoc4(colat/rad);
p0=colon/rad;
c0=cos(t0);
s0=sin(t0);
%
%  now do station coords.
%  use geocentric station colat
%
t2=geoc4(t1);
c1=cos(t2);
s1=sin(t2);
%
%  now calculate distance
%
dp=p1-p0;
co=c0*c1+s0*s1*cos(dp);
si=sqrt(1.d0-co*co);
del=atan2(si,co)*rad;
%
%  now calculate azimuth
%
caz=(c1-c0*co)/(si*s0);
dp2=-dp;
saz=-s1*sin(dp2)/si;
az=atan2(saz,caz)*rad;
%
%  change az to be between 0 and 360
%
if(az < 0.0)
    az=360.0 + az;
end;
